@@ -1,6 +1,7 @@
 from typing import List, Union
 
 from valo_api.endpoints_config import EndpointsConfig
+from valo_api.exceptions.valo_api_exception import ValoAPIException
 from valo_api.responses.error_response import ErrorResponse
 from valo_api.responses.website import WebsiteBannerV1
 from valo_api.utils.fetch_endpoint import fetch_endpoint
@@ -24,6 +25,6 @@ def get_website(
     response_data = response.json()
 
     if response.ok is False:
-        return ErrorResponse.from_dict(**response_data)
+        raise ValoAPIException(ErrorResponse.from_dict(**response_data))
 
     return [WebsiteBannerV1.from_dict(**banner) for banner in response_data["data"]]
